@@ -26,7 +26,7 @@
 
 FadeText::FadeText()
  : text(0),
-   font(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,300)),
+   font(Lum::OS::display->GetFont(300)),
    fadeStep(0),
    timerAction(new Lum::Model::Action())
 {
@@ -104,8 +104,6 @@ void FadeText::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  DrawBackground(x,y,w,h);
-
   if (fadeStep>0) {
     Lum::OS::DrawInfo *draw=GetDrawInfo();
 
